==> nextcloud-28.0.8.tgz: nextcloud/apps/oauth2/l10n/sk.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Váš klient nemá oprávnenie na pripojenie. Prosím informujte administrátora svojho klienta.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Vaša URL pre presmerovanie musí byť úplná. Napríklad: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Povoliť overenie kompatibilné s OAuth2 iných webových aplikácií.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Aplikácia OAuth2 umožňuje správcom nakonfigurovať vstavaný postup overovania tak, aby povolil autentifikáciu kompatibilnú s protokolom OAuth2 aj z iných webových aplikácií.",
    "OAuth 2.0 clients" : "Klienti OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 umožňuje externým službám požiadať o prístup k {instanceName}.",
    "Name" : "Názov",
    "Redirection URI" : "URI presmerovania",
    "Client Identifier" : "Identifikátor klienta",
    "Secret key" : "Tajný kľúč",
    "Delete client" : "Odstrániť klienta",
    "Add client" : "Pridať klienta",
    "Add" : "Pridať",
    "Delete" : "Zmazať",
    "Show client secret" : "Zobraziť tajomstvo klienta",
    "Hide client secret" : "Skryť klienta",
    "Secret" : "Tajný kľúč"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");

==> nextcloud-28.0.14.tgz: nextcloud/apps/oauth2/l10n/sk.js <==
OC.L10N.register(
    "oauth2",
    {
    "Your client is not authorized to connect. Please inform the administrator of your client." : "Váš klient nemá oprávnenie na pripojenie. Prosím informujte administrátora svojho klienta.",
    "Your redirect URL needs to be a full URL for example: https://yourdomain.com/path" : "Vaša URL pre presmerovanie musí byť úplná. Napríklad: https://yourdomain.com/path",
    "OAuth 2.0" : "OAuth 2.0",
    "Allows OAuth2 compatible authentication from other web applications." : "Povoliť overenie kompatibilné s OAuth2 iných webových aplikácií.",
    "The OAuth2 app allows administrators to configure the built-in authentication workflow to also allow OAuth2 compatible authentication from other web applications." : "Aplikácia OAuth2 umožňuje správcom nakonfigurovať vstavaný postup overovania tak, aby povolil autentifikáciu kompatibilnú s protokolom OAuth2 aj z iných webových aplikácií.",
    "OAuth 2.0 clients" : "Klienti OAuth 2.0",
    "OAuth 2.0 allows external services to request access to {instanceName}." : "OAuth 2.0 umožňuje externým službám požiadať o prístup k {instanceName}.",
    "Name" : "Názov",
    "Redirection URI" : "URI presmerovania",
    "Client Identifier" : "Identifikátor klienta",
    "Secret key" : "Tajný kľúč",
    "Delete client" : "Odstrániť klienta",
    "Make sure you store the secret key, it cannot be recovered." : "Uistite sa, že ste uložili tajný kľúč. Nedá sa obnoviť.",
    "Add client" : "Pridať klienta",
    "Add" : "Pridať",
    "Delete" : "Zmazať",
    "Show client secret" : "Zobraziť tajomstvo klienta",
    "Hide client secret" : "Skryť klienta"
},
"nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
